/*
This is the data set called `DETROIT' in the book `Subset selection in
regression' by Alan J.  Miller published in the Chapman & Hall series
of monographs on Statistics & Applied Probability, no.  40.  The data
are unusual in that a subset of three predictors can be found which
gives a very much better fit to the data than the subsets found from
the Efroymson stepwise algorithm, or from forward selection or
backward elimination.
 
The original data were given in appendix A of `Regression analysis and
its application: A data-oriented approach' by Gunst & Mason,
Statistics textbooks and monographs no.  24, Marcel Dekker.  It has
caused problems because some copies of the Gunst & Mason book do not
contain all of the data, and because Miller does not say which
variables he used as predictors and which is the dependent variable.
(HOMICIDE was the dependent variable, and the predictors were POLICE
...  W_EARN)
 
The data were collected by J.C.  Fisher and used in his paper:
"Homicide in Detroit: The Role of Firearms", Criminology, vol.14,
387-400 (1976)
 
The data are on the homicide rate in Detroit for the years 1961-1973.
 
N.B.  Each case takes two lines.
---------------------------------------------------------------------*/
data detroit;
 input
      POLICE UNEMPLOY MFGWORK GUNLIC GUNREG ARRESTS
      WMALES OWORK GOVWORK H_EARN
   #2 W_EARN HOMICIDE ACCIDENT ASSAULTS;
   retain year 1960;
   year+1;
   yr = mod(year-1960,10);
   wmales = wmales / 1000;   * express per 1000;
label
   POLICE   ='Full-time police per 100K'
   UNEMPLOY ='% Unemployed'
   MFGWORK  ='Manufacturing workers (1000s)'
   GUNLIC   ='Handgun licences per 100K'
   GUNREG   ='Handgun registrations per 100K'
   ARRESTS  ='% homicides cleared by arrests'
   WMALES   ='White males (1000s)'
   OWORK    ='Non-manufacturing workers (1000s)'
   GOVWORK  ='Government workers (1000s)'
   H_EARN    ='Average hourly earnings'
   W_EARN    ='Average weekly earnings'
 
   HOMICIDE  ='Homicides per 100K'
   ACCIDENT  ='Accident death rate per 100K'
   ASSAULTS  ='Assaults per 100K';
 
cards;
260.35  11.0  455.5   178.15  215.98  93.4  558724. 538.1  133.9   2.98
117.18  8.60  39.17   306.18
269.80  7.0   480.2   156.41  180.48  88.5  538584. 547.6  137.6   3.09
134.02  8.90  40.27   315.16
272.04  5.2   506.1   198.02  209.57  94.4  519171. 562.8  143.6   3.23
141.68  8.52  45.31   277.53
272.96  4.3   535.8   222.10  231.67  92.0  500457. 591.0  150.3   3.33
147.98  8.89  49.51   234.07
272.51  3.5   576.0   301.92  297.65  91.0  482418. 626.1  164.3   3.46
159.85  13.07 55.05   230.84
261.34  3.2   601.7   391.22  367.62  87.4  465029. 659.8  179.5   3.60
157.19  14.57 53.90   217.99
268.89  4.1   577.3   665.56  616.54  88.3  448267. 686.2  187.5   3.73
155.29  21.36 50.62   286.11
295.99  3.9   596.9   1131.21 1029.75 86.1  432109. 699.6  195.4   2.91
131.75  28.03 51.47   291.59
319.87  3.6   613.5   837.60  786.23  79.0  416533. 729.9  210.3   4.25
178.74  31.49 49.16   320.39
341.43  7.1   569.3   794.90  713.77  73.9  401518. 757.8  223.8   4.47
178.30  37.39 45.80   323.03
356.59  8.4   548.8   817.74  750.43  63.4  387046. 755.3  227.7   5.04
209.54  46.26 44.54   357.38
376.69  7.7   563.4   583.17  1027.38 62.5  373095. 787.0  230.9   5.47
240.05  47.24 41.03   422.07
390.19  6.3   609.3   709.59  666.50  58.9  359647. 819.8  230.2   5.76
258.05  52.33 44.17   473.01
;
