/*--------- --------------------------------------------------*
 | Heights of singers in the New York Choral Society in 1979. |
 | Source: Chambers, Cleveland, Kleiner, & Tukey, Graphical   |
 |   Methods for Data Analysis                                |
 *------------------------------------------------------------*/
%include goptions ;
goptions vsize=6in ftext=duplex htext=1.5;
proc format;
   value voice  1='Sopr1'  2='Sopr2' 3='Alto1' 4='Alto2'
                5='Tenor1' 6='Tenor2' 7='Bass1' 8='Bass2';
   value sexfmt 1='Female' 2='Male' other=' ';
data singers;
   input group gender $ voice $ n;
   drop i;
   do i=1 to n;
      input height @@ ;
      output;
      end;
cards;
1 F SOPRANO1 36
 64 62 66 65 60 61 65 66 65 63 67 65 62 65 68 65 63 65
 62 65 66 62 65 63 65 66 65 62 65 66 65 61 65 66 65 63
2 F SOPRANO2 30
 63 67 60 67 66 62 65 62 61 62 66 60 65 65 61 64 68 64
 63 62 64 62 64 65 60 65 70 63 67 66
3 F ALTO1 35
 65 62 68 67 67 63 67 66 63 72 62 61 66 64 60 61 66 66
 66 62 70 65 64 63 65 69 61 66 65 61 63 64 67 66 68
4 F ALTO2 27
 70 65 65 65 64 66 64 70 63 70 64 63 67 65 63 66 66 64
 64 70 70 66 66 66 69 67 65
5 M TENOR1 21
 69 72 71 66 76 74 71 66 68 67 70 65 72 70 68 64 73 66
 68 67 64
6 M TENOR2 21
 68 73 69 71 69 76 71 69 71 66 69 71 71 71 69 70 69 68
 70 68 69
7 M BASS1 39
 72 70 72 69 73 71 72 68 68 71 66 68 71 73 73 70 68 70
 75 68 71 70 74 70 75 75 69 72 71 70 71 68 70 75 72 66
 72 70 69
8 M BASS2 26
 72 75 67 75 74 72 72 74 72 72 74 70 66 68 75 68 70 72
 67 70 70 69 72 71 74 75
;
 
/*
--> qqplot of male vs. female parts
--> (notched) boxplot ;var voice; by gender;
*/
%include boxplot;
title1 h=1.5 'Heights of Choral Singers';
%boxplot(
         DATA=singers,CLASS=GROUP,VAR=height,
         CONNECT=1,              /* =0|1, 1=connect group medians      */
         FN=%STR(sqrt(N)),       /* Box width proportional to &FN      */
         notch=1,
         yorder=60 to 80 by 5,
         CLASSFMT=VOICE.,
         CLASSLAB=VOICE);
*proc print data=plotdat;
*boxplot(
         DATA=singers,CLASS=GENDER,VAR=height,
         connect=0,width=.25,
         yorder=60 to 80 by 5,
         CLASSFMT=SEXFMT.)
 
*-- get fitted (means) and residuals;
proc glm data=singers ;
   model height = group;
   output out=resids p=fitted r=residual;
proc standard m=0 data=resids out=resids;
   var fitted;
data fits;
   set resids;
   keep effect height;
   effect ='Fitted  ';  height = fitted  ; output;
   effect ='Residual';  height = residual; output;
proc format;
   value eff 1='Fitted' 2='Residual' other=' ';
title2 h=1.5 'Residual-Fit Spread Plot';
%boxplot(data=fits,class=Effect,var=Height, classfmt=eff.,
         connect=0,width=.25,
         yorder=-6 to 10 by 2);
 
%gfinish;
