/*               Copyright (c) 1994, Michael Friendly.               * 
 * Permission to use and distribute this program is granted as long  *
 * as this copyright notice remains intact.  Please acknowledge      *
 * Michael Friendly as author of this program in publications which  *
 * result from its use.                                              * 
 *-------------------------------------------------------------------*/
%macro inflplot(
         data=_last_,    /* Name of input data set */
         y=,             /* Criterion variable */
         x=,             /* Names of predictors */
         id=,
         bubble=cookd,
         lsize=1.5,
         lpos=5,
         bsize=10,
         gout=,
         );
 
%let nv = %numwords(&x);
%if &nv = 0 %then %do;
    %goto done;
    %end;
 
proc reg data=&data;
   model &y = &x / influence;
   %if &id ^= %str() %then %do;
      id &id;
      %end;
   output out=_diag_ h=hatvalue rstudent=rstudent
                     &bubble=&bubble;
 
data _label_;
   set _diag_ nobs=n;
   length xsys $1 ysys $1 function $8 position $1 text $12 color $8;
   retain xsys '2' ysys '2' function 'LABEL' color 'BLACK';
   retain tcrit hcrit;
   x=hatvalue;
   y=rstudent;
   %if &id ^= %str() %then %do;
      text = &id;
      %end;
   %else %do;
      text = put(_n_,3.0);
      %end;
   if _n_=1 then do;
      tcrit = tinv(.975, n-3);
      hcrit = 2 * (&nv+1)/n;
      put 'tcrit=' tcrit  '  hcrit=' hcrit;
      call symput('tcrit',put(tcrit,4.2));
      call symput('hcrit',put(hcrit,4.3));
      end;
   size=&lsize;
   position="&lpos";
  if abs(rstudent) > tcrit or
     hatvalue > 2 *(&nv+1)/n then do;
        output; end;
run;
 
proc gplot data=_diag_ &GOUT ;
  bubble rstudent * hatvalue = &bubble /
        annotate=_label_ frame
        vaxis=axis1 vminor=1
        vref=-&tcrit 0 &tcrit lvref=33
        href=&hcrit           lhref=33
        bsize=&bsize  ;
  axis1 label=(a=90 r=0);
  label rstudent='Studentized Residual'
        hatvalue='Leverage (Hat Value)';
  format hatvalue 3.2;
%done:
%mend;
 
%macro numwords(lst);
   %let i = 1;
   %let v = %scan(&lst,&i);
   %do %while (%length(&v) > 0);
      %let i = %eval(&i + 1);
      %let v = %scan(&lst,&i);
      %end;
   %eval(&i - 1)
%mend;
