/*-----------------------------------------------*
 * LABEL SAS  - Create an Annotate dataset to    *
 *     label observations in a scatterplot       *
 *-----------------------------------------------*
 *  Author:  Michael Friendly <FRIENDLY@YORKVM1> *
 * Created:  15 May 1991 12:27:15                *
 * Revised:  27 Apr 1993 09:47:03                *
 * Version:  1.2                                 *
 *                                               *
 *-----------------------------------------------*/
%macro label(data=_LAST_,
   x=,          /* X variable for scatterplot    */
   y=,          /* Y variable for scatterplot    */
   z=,          /* Z variable for G3D (optional) */
   xoff=0,      /* X-offset for label (constant  */
   yoff=0,      /* Y-offset for label    or      */
   zoff=0,      /* Z-offset for label  variable) */
   text=,       /* text variable or expression   */
   len=8,       /* length of text variable       */
   pos=,        /* position for label (+=out-just)*/
   sys=2,       /* XSYS & YSYS value             */
   color='BLACK',  /* label color (quote if const)*/
   size=1,      /* size of label                 */
   font=,       /* font for label                */
   subset=1,    /* expression to select points   */
   out=_label_  /* annotate data set produced    */
        );
 
%* -- pos can be a constant, an expression, or +;
%*    if a character constant, put "" around it;
%if "&pos" ^= "" %then %do;
   %if %length(&pos)=1 &
       %index(123456789ABCDEF,&pos) > 0
          %then %let pos="&pos" ;
   %end;
%if "&pos" = "+" %then
   %do;  %*-- Out-justify wrt means of x,y;
      proc summary data=&data;
         var &x &y;
         output out=&out mean=mx my;
   %end;
%else %let pos = "5";
 
data &out;
   set &data;
   keep x y xsys ysys position function size
        color text;
   length function $8 text $ &len position $1;
   retain xsys ysys "&sys" function 'LABEL';
   if &subset ;
   x = &x + &xoff ;
   y = &y + &yoff ;
   %if &z ^= %str() %then %do;
          retain zsys "&sys"; keep z zsys;
          z = &z + &zoff;
       %end;
   text=&text;          /* set label attributes */
   size=&size;
   color=&color;
   %if &font ^= %str() %then %do;
      keep style;
      style = "&font";
      %end;
   %if "&pos" = "+" %then
      %do;
         retain mx my;
         if _n_=1 then set &out;
         if x > mx then
            if y > my then position = '3';
                      else position = '9';
            else
            if y > my then position = '1';
                      else position = '7';
      %end;
   %else %str(position=&pos;);
%mend label;
