/*-------------------------------------------------------------------*
 * ORDPLOT SAS    Plots to diagnose form of discrete frequency       *
 *                distributions: Poisson, Binomial, Neg. Binomial,   *
 *                Log series                                         *
 *-------------------------------------------------------------------*
 *  Author:  Michael Friendly            <FRIENDLY@YORKVM1>          *
 * Created:  9 May 1991 11:30:54                                     *
 * Revised:  9 May 1991 11:30:54                                     *
 * Version:  1.0                                                     *
 *                                                                   *
 *-------------------------------------------------------------------*/
/*               Copyright (c) 1994, Michael Friendly.               * 
 * Permission to use and distribute this program is granted as long  *
 * as this copyright notice remains intact.  Please acknowledge      *
 * Michael Friendly as author of this program in publications which  *
 * result from its use.                                              * 
 *-------------------------------------------------------------------*/

 %macro ordplot(
     data=_last_,       /* input data set                           */
     count=,            /* basic count variable                     */
     freq=,             /* number of occurrences of count           */
     label=);           /* Horizontal (count) label                 */
 
%if &label=%str() %then %let label=&count;
proc means data=&data noprint;
   var &count;
   weight &freq;
   output out=sum sumwgt=N sum=sum mean=mean min=min max=max;
proc print data=sum;
data ordplot;
   set &data;
   if _n_=1 then set sum(drop=_type_ _freq_);
   k = &count;
   nk= &freq;                  * n(k);
   nk1 = lag(&freq);           * n(k-1);
   y =  k * nk / nk1;
   if nk > 1
      then wk = sqrt(nk-1);            * weight for regression line;
      else wk = 0;
proc print data=ordplot;
   id k;
   var nk nk1 wk y;
   sum nk;
 
proc reg data=ordplot outest=parms;
   weight wk;
   model y =  k;
data stats;
   set parms (keep=k intercep);
   set sum   (keep=mean min max);
   drop k intercep;
   length text type parm $30 function $8;
   xsys='1'; ysys='1';
   x=6;   y=92;
   function = 'LABEL';
   size = 1.4;
   style = 'DUPLEX';
   color = 'RED';
   position='3'; text ='slope =   '||put(k,f6.3);      output;
   position='6'; text ='intercept='||put(intercep,f6.3); output;
 
   *-- Determine type of distribution;
   select;
      when (abs(k) < .1) do;
         type = 'Poisson';
         parm = 'lambda = '||put(intercep,6.3);
         end;
      when (k < -.1) do;
         type = 'Binomial';
         p = (k/(k-1));
         parm = 'p = '||put(p,6.3);
         end;
      otherwise do;  * positive slope;
         if intercep >-.05 then do;
            type = 'Negative binomial';
            parm = 'p ='||put(1-k,6.3);
            end;
         else do;
            type = 'Logarithmic series';
            parm = 'theta ='||put(k,6.3);
            end;
         end;
      end;
   y = 80;
   position='3'; text ='type: ' ||type;   output;
   position='6'; text ='parm: ' ||parm;   output;
 
   *-- Draw (weighted) regression line;
   xsys='2'; ysys='2';
   x=min; y = intercep + k * x; function='MOVE'; output;
   x=max; y = intercep + k * x; function='DRAW'; output;
 
proc gplot data=ordplot;
   plot y * k / anno=stats vaxis=axis1 haxis=axis2;
   symbol v=- h=2 i=rl l=33 c=black;
   axis1 label=(a=90 r=0 f=duplex h=1.4
          'Frequency Ratio, (k n(k) / n(k-1))' )
         value=(h=1.3);
   axis2 offset=(3) minor=none
         label=(f=duplex h=1.4 "k  (&label)")
         value=(h=1.3);
%mend;
