title 'Canonical correlation (CORR matrix input)';
/*  Data from Dunham (1977), Acad.Mgt.J., 20, 42-65
    Sample: 784 executives from a large retail merchandizing corp
    See Johnson & Wichern, Example 10.5 */
data jobsat(type=corr);
   input _name_ $1-6 _type_ $8-11
         x1-x5 y1-y7;
   label x1='Feedback'  x2='Task Significance' x3='Task Variety'
         x4='Task Identity' x5='Autonomy'
         y1='Supervisor Satisfaction'  y2='Career-Future Sat'
         y3='Financial Satisfaction' y4='Workload Satisfaction'
         y5='Company Satisfaction' y6='Kind-of-work Sat'
         y7='General Satisfaction';
/*  Note:
  The _NAME_ values *must* match the variable names for valid
  correlation matrix input.  Only the lower half need be entered.
*/
list;cards;
X1     CORR 1   .   .   .   .   .   .   .   .   .   .   .
X2     CORR .49 1   .   .   .   .   .   .   .   .   .   .
X3     CORR .53 .57 1   .   .   .   .   .   .   .   .   .
X4     CORR .49 .46 .48 1   .   .   .   .   .   .   .   .
X5     CORR .51 .53 .57 .57 1   .   .   .   .   .   .   .
Y1     CORR .33 .30 .31 .24 .38 1   .   .   .   .   .   .
Y2     CORR .32 .21 .23 .22 .32 .43 1   .   .   .   .   .
Y3     CORR .20 .16 .14 .12 .17 .27 .33 1   .   .   .   .
Y4     CORR .19 .08 .07 .19 .23 .24 .26 .25 1   .   .   .
Y5     CORR .30 .27 .24 .21 .32 .34 .54 .46 .28 1   .   .
Y6     CORR .37 .35 .37 .29 .36 .37 .32 .29 .30 .35 1   .
Y7     CORR .21 .20 .18 .16 .27 .40 .58 .45 .27 .59 .31 1
       N    784 784 784 784 784 784 784 784 784 784 784 784
;
proc cancorr data=jobsat
     redundancy smc    /* Squared Multiple Rs */
     ncan=2            /* Print only 2 canonical variates */
     vprefix = job   vname='Job characteristics'
     wprefix = sat   wname='Satisfaction measures';
   var  x1-x5;
   with y1-y7;
   run;
