 /****************************************************************/
 /*          S A S   S A M P L E   L I B R A R Y                 */
 /*                                                              */
 /*    NAME: CARPREF                                             */
 /*   TITLE: PRINCIPAL COMPONENTS ANALYSIS OF CAR PREFERENCES    */
 /* PRODUCT: SAS                                                 */
 /*  SYSTEM: OS CMS VSE                                          */
 /*    KEYS: FACTOR MULTIV                                       */
 /*   PROCS: CORR FACTOR PLOT SCORE SORT TRANSPOSE               */
 /*                                                              */
 /****************************************************************/
 
*---------------------------------------------------------------------+
|   DEFINE MACRO FOR NAMES OF RATINGS                                 |
+---------------------------------------------------------------------;
 
MACRO VARMAC
   MPG RELIABLE ACCEL BRAKING HANDLING RIDE VISIBLE COMFORT QUIET CARGO
%
 
*---------------------------------------------------------------------+
|   READ DATA                                                         |
+---------------------------------------------------------------------+
|  Preference ratings of 17 automobiles were collected from 25        |
|  subjects on a 0-9 scale. In addition, measures of performance and  |
|  comfort were obtained from a consumer magazine. In this analysis,  |
|  the subjects are treated as variables, and the automobiles as      |
|  observations in an inverse component analysis.                     |
|---------------------------------------------------------------------;
DATA CARS;
TITLE 'CAR PREFERENCES';
     LENGTH ORIGIN $8;
     INPUT MAKE $1-10 MODEL $12-22 @24 (VARMAC) (1.) ORIGIN $35
           @37 (PREF1-PREF25) (1.);
     ID = SUBSTR(MODEL,1,3);
     IF ORIGIN='E'|ORIGIN='J' THEN IMPORT='YES';
                              ELSE IMPORT='NO';
     IF ORIGIN='A' THEN ORIGIN='AMC     ';
     IF ORIGIN='C' THEN ORIGIN='CHRYSLER';
     IF ORIGIN='F' THEN ORIGIN='FORD    ';
     IF ORIGIN='G' THEN ORIGIN='GMC     ';
     IF ORIGIN='E' THEN ORIGIN='EUROPE  ';
     IF ORIGIN='J' THEN ORIGIN='JAPAN   ';
CARDS;
CADILLAC   ELDORADO    3234543533 G 0807990491240508971093809
CHEVROLET  CHEVETTE    5335425223 G 0051200423451043003515698
CHEVROLET  CITATION    4155555525 G 0453305814161643544747795
CHEVROLET  MALIBU      3333444544 G 0627400723121345545668658
FORD       FAIRMONT    3324345434 F 0224006715021443530648655
FORD       MUSTANG     3244323222 F 0507197705021101850657555
FORD       PINTO       4134313222 F 0021000303030201500514078
HONDA      ACCORD      5554533433 J 9556897609699952998975078
HONDA      CIVIC       5545435434 J 8436709507488852567765075
LINCOLN    CONTINENTAL 2453353555 F 0708990592230409962091909
PLYMOUTH   GRAN FURY   2134353535 C 0706000434101107333458708
PLYMOUTH   HORIZON     4345535235 C 0305005635461302444675655
PLYMOUTH   VOLARE      2153333424 C 0405003614021602754476555
PONTIAC    FIREBIRD    1153551231 G 1007895613201206958265907
VOLKSWAGEN DASHER      5355545435 E 8458696508877795377895000
VOLKSWAGEN RABBIT      5454535424 E 8458509709695795487885000
VOLVO      DL          4524555555 E 9989998909999987989919000
;
*PROC PRINT;
*     ID MAKE MODEL ORIGIN IMPORT;
 
 
*---------------------------------------------------------------------+
|   COMPUTE STANDARDIZED PRINCIPAL COMPONENT SCORES                   |
+---------------------------------------------------------------------+
| Since there are more variables (subjects) than observations (cars)  |
|FACTOR complains that the matrix is singular. However, since PRIORS  |
|and METHOD are not specified, we get a METHOD=PRINCIPAL analysis     |
|with PRIORS=ONE and the singularity can be ignored. The points in    |
|the factor space show preference vectors for each subject.           |
+---------------------------------------------------------------------;
 
PROC FACTOR DATA=CARS
     SCREE N=2 SCORE
     OUT=FAC
     NOCORR
     OUTSTAT=FACT
     PLOT NPLOT=2;
     VAR PREF1-PREF25;
TITLE2 'PRINCIPAL COMPONENTS OF THE PREFERENCES';
Data FACT;
     Set FACT;
     If _TYPE_='CORR' then delete;
PROC PRINT data=FACT;
     Title2 'OUTSTAT data set from FACTOR';
PROC SCORE DATA=CARS SCORE=FACT OUT=PRIN;
     VAR PREF1-PREF25;
 
*---------------------------------------------------------------------+
|   LIST CARS SORTED BY PRINCIPAL COMPONENTS                          |
+---------------------------------------------------------------------;
 
PROC SORT DATA=PRIN;      BY FACTOR1;
PROC PRINT;
     ID MAKE MODEL;       VAR FACTOR1;
     TITLE2 'SORTED BY FIRST PRINCIPAL COMPONENT';
PROC SORT DATA=PRIN;      BY FACTOR2;
PROC PRINT;
     ID MAKE MODEL;       VAR FACTOR2;
     TITLE2 'SORTED BY SECOND PRINCIPAL COMPONENT';
 
*---------------------------------------------------------------------+
|   PLOT PRINCIPAL COMPONENTS                                         |
+---------------------------------------------------------------------;
 
PROC PLOT DATA=PRIN;
     PLOT FACTOR2*FACTOR1=ORIGIN
       /HAXIS=-1.5 TO 2.5 BY .5 VAXIS=-1.5 TO 2.5 BY .5 VPOS=43;
TITLE2 'PLOT OF THE FIRST TWO PRINCIPAL COMPONENTS';
PROC IDPLOT METRIC;
     PLOT FACTOR2*FACTOR1 = ID
       /HINC= .5 VINC= .5 VPOS=43;
 
*---------------------------------------------------------------------+
|   PLOT BOTH CARS AND COMPONENT PATTERN                              |
+---------------------------------------------------------------------;
 
DATA PAT; SET FACT;
     DROP _TYPE_;
     IF _TYPE_='PATTERN';
PROC TRANSPOSE OUT=PAT;
DATA ZERO;                   /* Define zero point for plot */
     _NAME_='+       ';
     FACTOR1=0;
     FACTOR2=0;
DATA BIPLOT;
     SET PAT ZERO PRIN(IN=INPRIN);
     IF INPRIN THEN _NAME_='.';
Proc Print;
     Var _NAME_ FACTOR1 FACTOR2 ORIGIN MAKE MODEL;
     Title3 'BIPLOT data set';
PROC PLOT;
     PLOT FACTOR2*FACTOR1=_NAME_
     /HAXIS=-1.5 TO 2.5 BY .5 VAXIS=-1.5 TO 2.5 BY .5 VPOS=43;
TITLE3 'SHOWING BOTH CARS AND PREFERENCE VECTORS';
 
*---------------------------------------------------------------------+
|   PLOT BOTH CARS AND ATTRIBUTE VECTORS                              |
+---------------------------------------------------------------------;
 
PROC CORR DATA=PRIN NOSIMPLE NOPROB OUTP=ATTCOR;
     VAR FACTOR1-FACTOR2;
     WITH VARMAC;
DATA ATTCOR; SET ATTCOR;
     DROP _TYPE_;
     IF _TYPE_='CORR';
DATA BIPLOT;
     SET ATTCOR ZERO PRIN(IN=INPRIN);
     IF INPRIN THEN _NAME_='.';
PROC PLOT;
     PLOT FACTOR2*FACTOR1=_NAME_
     /HAXIS=-1.5 TO 2.5 BY .5 VAXIS=-1.5 TO 2.5 BY .5 VPOS=43;
TITLE3 'SHOWING BOTH CARS AND ATTRIBUTE VECTORS';
run;
