 /*--------------------------------------------------------------
  *
  *                  SAS/STAT TEST LIBRARY
  *
  *       NAME: calis13
  *    SUPPORT: Wolfgang M. Hartmann
  *     UPDATE:
  *  REFERENCE: Ability and Aspiration, LISREL VI (1985, p.III.5)
  *             Data of CALSYN & KENNY (1977)
  * EVALUATION:
  *   FUNCTION: First Order Confirmatory FA model.
  *             Long output contains (p. III.5-20):
  *             parameter specification
  *             initial estimates
  *             maximum-likelihood estimates
  *             R-squared values
  *             coefficient of determination
  *             goodness-of-fit measures
  *             standard errors and t-values
  *             variances and covariances
  *             modification indices
  *       MISC:
  *
  --------------------------------------------------------------*/
 
 OPTIONS LS=120 PS=60;
TITLE 'TEST13: Ability and Aspiration, LISREL VI, p. III.5';
TITLE2 'Data of CALSYN & KENNY (1977)';
DATA CALKEN(TYPE=CORR);
   _TYPE_ = 'CORR'; INPUT _NAME_ $ V1-V6;
   LABEL V1='Self-concept of ability'
         V2='Perceived parental evaluation'
         V3='Perceived teacher evaluation'
         V4='Perceived friends evaluation'
         V5='Educational aspiration'
         V6='College plans';
   CARDS;
V1    1.      .      .      .      .      .
V2     .73   1.      .      .      .      .
V3     .70    .68   1.      .      .      .
V4     .58    .61    .57   1.      .      .
V5     .46    .43    .40    .37   1.      .
V6     .56    .52    .48    .41    .72   1.
  ;
 
PROC CALIS DATA=CALKEN METHOD=MAX TECH=NR EDF=555 short mod PDE;
 FACTOR N=2;
 MATRIX _F_                           /* loadings */
           [ ,1] = LAM1-LAM4 ,        /* factor 1 */
           [ ,2] = 4 * 0 LAM5 LAM6 ;  /* factor 2 */
 MATRIX _P_
           [1,1] = 2 * 1. ,
           [1,2] = COR;
 RUN;
 
 
/* Alternative way to specify the same model */
/*  using linear equations
 
PROC CALIS DATA=CALKEN METHOD=MAX TECH=LM EDF=555 ALL PDE;
 LINEQS
      V1 = LAM1 F1         + E1 ,
      V2 = LAM2 F1         + E2 ,
      V3 = LAM3 F1         + E3 ,
      V4 = LAM4 F1         + E4 ,
      V5 =         LAM5 F2 + E5 ,
      V6 =         LAM6 F2 + E6 ;
 STD
      E1-E6 = EPS: ,
      F1-F2 = 2 * 1. ;
 COV
      F1 F2 = COR ;
 RUN;
*/
