 /*--------------------------------------------------------------
  *
  *                  SAS/STAT TEST LIBRARY
  *
  *       NAME: calis16
  *    SUPPORT: Wolfgang M. Hartmann
  *     UPDATE:
  *  REFERENCE: Nine Psychological Variables, LISREL VI (1985, p.III.106)
  *             Data of HOLZINGER & SWINEFORD (1937)
  * EVALUATION:
  *   FUNCTION: First Order Confirmatory FA models
  *             Different models show use of modification indices.
  *             Long output contains (LISREL p. III.108-122):
  *             CORR matrix with determinant
  *             parameter specification
  *             maximum-likelihood estimates
  *             R-squared values
  *             coefficient of determination
  *             standard errors and t-values
  --------------------------------------------------------------*/
 
TITLE 'TEST16: Nine Psychological Variables, LISREL VI, p. III.106';
TITLE2 'Confirmatory Factor Analysis, Data of Holzinger & Swineford (1937)';
DATA HOLZING(TYPE=CORR);
   _TYPE_ = 'CORR'; INPUT _NAME_ $ V1-V9;
   LABEL V1='Visual perception' V2='Cubes'
         V3='Lozenges' V4='Paragraph comprehension'
         V5='Sentence completion' V6='Word meaning'
         V7='Addition' V8='Counting dots'
         V9='Straight-curved capitals' ;
   CARDS;
V1    1.       .      .      .      .      .      .      .      .
V2     .318   1.      .      .      .      .      .      .      .
V3     .436   .419   1.      .      .      .      .      .      .
V4     .335   .234   .323   1.      .      .      .      .      .
V5     .304   .157   .283   .722   1.      .      .      .      .
V6     .326   .195   .350   .714   .685   1.      .      .      .
V7     .116   .057   .056   .203   .246   .170   1.      .      .
V8     .314   .145   .229   .095   .181   .113   .585   1.      .
V9     .489   .239   .361   .309   .345   .280   .408   .512   1.
  ;
 
PROC CALIS DATA=HOLZING METHOD=MAX TECH=LM EDF=144 short mod PDE;
 TITLE3 'Model A: Restricted Oblique Clusters (24 df)';
 FACTOR N=3;
 MATRIX _F_                        /* factor loadings */
           [ ,1] = 3 * L: ,
           [ ,2] = 3 * 0 3 * L: ,
           [ ,3] = 6 * 0 3 * L: ;
 MATRIX _P_                        /* factor correlations */
           [1, ] = 1. ,
           [2, ] = C: 1. ,
           [3, ] = 2 * C: 1. ;
 MATRIX _U_                        /* unique variances */
           [1,1] = EPS1-EPS9 ;
 BOUNDS
      EPS1-EPS9 >= 0.;             /* must be non-negative */
 RUN;
/*
PROC CALIS DATA=HOLZING METHOD=MAX TECH=LM EDF=144 short mod;
 TITLE3 'Model A: Restricted Oblique Clusters (24 df)';
 LINEQS
      V1 = L: F1              + E1,
      V2 = L: F1              + E2,
      V3 = L: F1              + E3,
      V4 =       L: F2        + E4,
      V5 =       L: F2        + E5,
      V6 =       L: F2        + E6,
      V7 =              L: F3 + E7,
      V8 =              L: F3 + E8,
      V9 =              L: F3 + E9;
 STD
      E1-E9 = EPS1-EPS9 ,
      F1-F3 = 3 * 1. ;
 BOUNDS
      EPS1-EPS9 >= 0.;
 COV
      F1-F3 = C: ;
 RUN;
*/
 
PROC CALIS DATA=HOLZING METHOD=MAX TECH=LM EDF=144 short;
 TITLE3 'Model B: 23 degrees of freedom (F[9,1] free)';
 FACTOR N=3;
 MATRIX _F_
           [ ,1] = 3 * L: 5 * 0. L:,
           [ ,2] = 3 * 0 3 * L: ,
           [ ,3] = 6 * 0 3 * L: ;
 MATRIX _P_
           [1, ] = 1. ,
           [2, ] = C: 1. ,
           [3, ] = 2 * C: 1. ;
 MATRIX _U_
           [1,1] = EPS1-EPS9 ;
 BOUNDS
      EPS1-EPS9 >= 0.;
 RUN;
/*
PROC CALIS DATA=HOLZING METHOD=MAX TECH=LM EDF=144 short;
 TITLE3 'Model B: 23 degrees of freedom (F[9,1] free)';
 LINEQS
      V1 = L: F1              + E1,
      V2 = L: F1              + E2,
      V3 = L: F1              + E3,
      V4 =       L: F2        + E4,
      V5 =       L: F2        + E5,
      V6 =       L: F2        + E6,
      V7 =              L: F3 + E7,
      V8 =              L: F3 + E8,
      V9 = L: F1      + L: F3 + E9;
 STD
      E1-E9 = EPS1-EPS9 ,
      F1-F3 = 3 * 1. ;
 BOUNDS
      EPS1-EPS9 >= 0.;
 COV
      F1-F3 = C: ;
 RUN;
*/
