 /*--------------------------------------------------------------
  *
  *                  SAS/STAT TEST LIBRARY
  *
  *       NAME: calis32
  *    SUPPORT: Wolfgang M. Hartmann
  *     UPDATE:
  *  REFERENCE: Vocabulary Tests, JOERESKOG (1978, pp.451)
  *             data of LORD (1957)
  * EVALUATION:
  *   FUNCTION: First Order Confirmatory FA
  *             Singular central model matrices
  *             Testing various models by means of Chi-squared values
  *             ML estimates and Chi-squared values.
  *       MISC:
  *
  --------------------------------------------------------------*/
 
TITLE 'TEST32: Vocabulary Test Data, LORD (1957)';
TITLE2 'Confirmatory Factor Analysis, JOERESKOG (1978, p. 452)';
DATA LORD(TYPE=COV);
   _TYPE_ = 'COV'; INPUT _NAME_ $ X1-X2 Y1-Y2;
   CARDS;
 
X1    86.3979      .         .         .
X2    57.7751    86.2632     .         .
Y1    56.8651    59.3177   97.2850     .
Y2    58.8986    59.6683   73.8201   97.8192
  ;
 
 
PROC CALIS DATA=LORD COV METHOD=MAX TECH=LM EDF=648 ALL;
 TITLE3 'Hypothesis 1, JOERESKOG (1978, p. 452)';
 FACTOR N=2;
 MATRIX _F_
           [ ,1] = 2 * Z1 ,
           [ ,2] = 2 * 0 2 * Z3 ;
 MATRIX _P_
           [1, ] = 1. ,
           [2, ] = 1. 1. ;
 MATRIX _U_
           [1,1] = 2 * EPS1 2 * EPS3 ;
 RUN;
 
 
PROC CALIS DATA=LORD COV METHOD=MAX TECH=LM EDF=648 ALL;
 TITLE3 'Hypothesis 1, JOERESKOG (1978, p. 452)';
 COSAN F(2, GEN) * PHI(2, SYM) + U(4, DIA);
 MATRIX F
           [ ,1] = 2 * Z1 ,
           [ ,2] = 2 * 0 2 * Z3 ;
 MATRIX PHI
           [1, ] = 1. ,
           [2, ] = 1. 1. ;
 MATRIX U
           [1,1] = 2 * EPS1 2 * EPS3 ;
 RUN;
 
 
PROC CALIS DATA=LORD COV METHOD=MAX TECH=LM EDF=648 ALL;
 TITLE3 'Hypothesis 1, JOERESKOG (1978, p. 452)';
 LINEQS
      X1 = Z1 F1 + E1 ,
      X2 = Z1 F1 + E2 ,
      Y1 = Z3 F2 + E3 ,
      Y2 = Z3 F2 + E4 ;
 STD
      E1-E4 = 2 * EPS1 2 * EPS3 ,
      F1-F2 = 2 * 1. ;
 COV
      F2 F1 = 1. ;
 RUN;
 
 
PROC CALIS DATA=LORD COV METHOD=LSMAX TECH=LM EDF=648 ALL;
 TITLE3 'Hypothesis 2, JOERESKOG (1978, p. 452)';
 FACTOR N=2;
 MATRIX _F_
           [ ,1] = 2 * Z1 ,
           [ ,2] = 2 * 0 2 * Z3 ;
 MATRIX _P_
           [1, ] = 1. ,
           [2, ] = RO 1. ;
 MATRIX _U_
           [1,1] = 2 * EPS1 2 * EPS3 ;
 RUN;
 
PROC CALIS DATA=LORD COV METHOD=LSMAX TECH=LM EDF=648 ALL;
 TITLE3 'Hypothesis 2, JOERESKOG (1978, p. 452)';
 COSAN F(2, GEN) * PHI(2, SYM) + U(4, DIA);
 MATRIX F
           [ ,1] = 2 * Z1 ,
           [ ,2] = 2 * 0 2 * Z3 ;
 MATRIX PHI
           [1, ] = 1. ,
           [2, ] = RO 1. ;
 MATRIX U
           [1,1] = 2 * EPS1 2 * EPS3 ;
 RUN;
 
 
PROC CALIS DATA=LORD COV METHOD=LSMAX TECH=LM EDF=648 ALL;
 TITLE3 'Hypothesis 2, JOERESKOG (1978, p. 452)';
 LINEQS
      X1 = Z1 F1 + E1 ,
      X2 = Z1 F1 + E2 ,
      Y1 = Z3 F2 + E3 ,
      Y2 = Z3 F2 + E4 ;
 STD
      E1-E4 = 2 * EPS1 2 * EPS3 ,
      F1-F2 = 2 * 1. ;
 COV
      F2 F1 = RO ;
 RUN;
 
 
PROC CALIS DATA=LORD COV METHOD=MAX TECH=LM EDF=648 ALL;
 TITLE3 'Hypothesis 3, JOERESKOG (1978, p. 452)';
 FACTOR N=2;
 MATRIX _F_
           [ ,1] = 2 * Z: ,
           [ ,2] = 2 * 0 2 * Z: ;
 MATRIX _P_
           [1, ] = 1. ,
           [2, ] = 1. 1. ;
 MATRIX _U_
           [1,1] = 4 * EPS: ;
 RUN;
 
PROC CALIS DATA=LORD COV METHOD=MAX TECH=LM EDF=648 ALL;
 TITLE3 'Hypothesis 3, JOERESKOG (1978, p. 452)';
 COSAN F(2, GEN) * PHI(2, SYM) + U(4, DIA);
 MATRIX F
           [ ,1] = 2 * Z: ,
           [ ,2] = 2 * 0 2 * Z: ;
 MATRIX PHI
           [1, ] = 1. ,
           [2, ] = 1. 1. ;
 MATRIX U
           [1,1] = 4 * EPS: ;
 RUN;
 
 
PROC CALIS DATA=LORD COV METHOD=MAX TECH=LM EDF=648 ALL;
 TITLE3 'Hypothesis 3, JOERESKOG (1978, p. 452)';
 LINEQS
      X1 = Z: F1 + E1 ,
      X2 = Z: F1 + E2 ,
      Y1 = Z: F2 + E3 ,
      Y2 = Z: F2 + E4 ;
 STD
      E1-E4 = EPS: ,
      F1-F2 = 2 * 1. ;
 COV
      F2 F1 = 1. ;
 RUN;
 
 
 
