 /*--------------------------------------------------------------
  *
  *                  SAS/STAT TEST LIBRARY
  *
  *       NAME: calis33
  *    SUPPORT: Wolfgang M. Hartmann
  *     UPDATE:
  *  REFERENCE: Speed Factor Data, JOERESKOG (1978, p.453-455)
  *             Data of LORD (1956)
  * EVALUATION:
  *   FUNCTION: First Order Confirmatory FA
  *             ML estimates and Chi-squared values.
  *       MISC:
  *
  --------------------------------------------------------------*/
 
 OPTIONS LS=120 PS=60;
 
TITLE 'TEST33: Speed Factor Data, LORD (1956)';
TITLE2 'Confirmatory Factor Analysis, JOERESKOG (1978, p. 454-5)';
DATA LORD(TYPE=CORR);
   INPUT _TYPE_ $ _NAME_ $ V1-V6 I1-I6 R1-R6;
   LABEL V1='Vocabulary L1'      V2='Vocabulary L2'
         V3='Vocabulary M'       V4='Vocabulary S1'
         V5='Vocabulary S2'      V6='Vocabulary S3'
         I1='Intersections L1'   I2='Intersections L2'
         I3='Intersections M'    I4='Intersections S1'
         I5='Intersections S2'   I6='Intersections S3'
         R1='Arith Reasoning L1' R2='Arith Reasoning L2'
         R3='Arith Reasoning M'  R4='Arith Reasoning S1'
         R5='Arith Reasoning S2' R6='Arith Reasoning S3';
   CARDS;
CORR V1    1.00    .      .      .      .      .      .      .      .
            .      .      .      .      .      .      .      .      .
CORR V2     .67   1.00    .      .      .      .      .      .      .
            .      .      .      .      .      .      .      .      .
CORR V3     .71    .69   1.00    .      .      .      .      .      .
            .      .      .      .      .      .      .      .      .
CORR V4     .62    .65    .66   1.00    .      .      .      .      .
            .      .      .      .      .      .      .      .      .
CORR V5     .69    .70    .74    .77   1.00    .      .      .      .
            .      .      .      .      .      .      .      .      .
CORR V6     .64    .65    .70    .76    .85   1.00    .      .      .
            .      .      .      .      .      .      .      .      .
CORR I1     .15    .18    .11    .16    .12    .09   1.00    .      .
            .      .      .      .      .      .      .      .      .
CORR I2     .06    .14    .08    .14    .06    .07    .72   1.00    .
            .      .      .      .      .      .      .      .      .
CORR I3     .10    .18    .12    .18    .10    .12    .71    .77   1.00
            .      .      .      .      .      .      .      .      .
CORR I4     .12    .17    .09    .19    .13    .14    .70    .71    .75
           1.00    .      .      .      .      .      .      .      .
CORR I5     .09    .13    .08    .17    .11    .10    .70    .74    .76
            .80   1.00    .      .      .      .      .      .      .
CORR I6     .08    .12    .08    .16    .10    .11    .70    .75    .77
            .79    .83   1.00    .      .      .      .      .      .
CORR R1     .30    .32    .27    .28    .29    .27    .34    .30    .34
            .32    .31    .33   1.00    .      .      .      .      .
CORR R2     .25    .31    .26    .29    .27    .29    .36    .30    .36
            .30    .29    .31    .54   1.00    .      .      .      .
CORR R3     .29    .34    .30    .32    .31    .35    .30    .30    .34
            .31    .29    .32    .61    .56   1.00    .      .      .
CORR R4     .28    .26    .30    .36    .35    .38    .29    .28    .33
            .31    .29    .36    .55    .54    .63   1.00    .      .
CORR R5     .27    .29    .30    .33    .35    .35    .34    .28    .34
            .35    .34    .37    .53    .55    .58    .63   1.0     .
CORR R6     .28    .30    .31    .38    .36    .39    .26    .23    .25
            .27    .25    .31    .51    .53    .57    .64    .61   1.00
STD  DV    9.30   9.29   9.73   9.86   9.61   9.89   9.55   9.67   9.81
           9.80   9.83   9.88   9.05   9.67   9.73   9.91   9.85   9.83
  ;
 
PROC CALIS DATA=LORD COV METHOD=MAX TECH=LM EDF=648 short;
 VAR V1 V2 V4 V5 V6  I1 I2 I4 I5 I6  R1 R2 R4 R5 R6;
 title3 'Model 6: Three power factors, three speed factors';
 FACTOR N=6;
 MATRIX _F_
           [ ,1] =  5 * Z: ,
           [ ,2] =  5 * 0. 5 * Z: ,
           [ ,3] = 10 * 0. 5 * Z: ,
           [ ,4] =  2 * 0. 3 * Z: ,
           [ ,5] =  7 * 0. 3 * Z: ,
           [ ,6] = 12 * 0. 3 * Z: ;
 MATRIX _P_
           [1, ] = 1. ,
           [2, ] = C: 1. ,
           [3, ] = 2 * C: 1. ,
           [4, ] = 3 * 0. 1. ,
           [5, ] = 3 * 0. C: 1. ,
           [6, ] = 3 * 0. 2 * C: 1. ;
 MATRIX _U_
           [1,1] = EPS1-EPS15 ;
 BOUNDS
      EPS1-EPS15 >= 0.;
 RUN;
 
/*
PROC CALIS DATA=LORD COV METHOD=LSMAX TECH=LM GTOL=.00001 MAXIT=100
           MAXFU=500 EDF=648 ;
 LINEQS
      V1  = Z: F1         + E1 ,
      V2  = Z: F1         + E2 ,
      V4  = Z: F1 + Z: F4 + E3 ,
      V5  = Z: F1 + Z: F4 + E4 ,
      V6  = Z: F1 + Z: F4 + E5 ,
      I1  = Z: F2         + E6 ,
      I2  = Z: F2         + E7 ,
      I4  = Z: F2 + Z: F5 + E8  ,
      I5  = Z: F2 + Z: F5 + E9  ,
      I6  = Z: F2 + Z: F5 + E10 ,
      R1  = Z: F3         + E11 ,
      R2  = Z: F3         + E12 ,
      R4  = Z: F3 + Z: F6 + E13 ,
      R5  = Z: F3 + Z: F6 + E14 ,
      R6  = Z: F3 + Z: F6 + E15 ;
 STD
      E1-E15 = EPS1-EPS15 ,
      F1-F6 = 6 * 1. ;
 COV
      F1 F2 F3 = C: ,
      F4 F5 F6 = C: ;
 BOUNDS
      EPS1-EPS15 >= 0.;
 RUN;
*/
 
