Options LS=95;
Title 'Regression using the SWEEP operator in IML';
DATA WATERUSE;
     INPUT X1-X4 Y;
     Title2 'Water use data';
 
label X1='AVERAGE MONTHLY TEMPERATURE (F)'
      X2='AMOUNT OF PRODUCTION (M POUNDS)'
      X3='NUMBER OF OPERATING DAYS IN THE MONTH'
      X4='NUMBER OF PERSONS ON THE MONTHLY PAYROLL'
       Y='MONTHLY WATER USAGE (GALLONS)' ;
*  Determine a regression equation to explain the  amount of water
   used by the production facilities each month ;
CARDS ;
58.8  7107 21 129 3067
65.2  6373 22 141 2828
70.9  6796 22 153 2891
77.4  9208 20 166 2994
79.3 14792 25 193 3082
81.0 14564 23 189 3898
71.9 11964 20 175 3502
63.9 13526 23 186 3060
54.5 12656 20 190 3211
39.5 14119 20 187 3286
44.5 16691 22 195 3542
43.6 14571 19 206 3125
56.0 13619 22 198 3022
64.7 14575 22 192 2922
73.0 14556 21 191 3950
78.9 18573 21 200 4488
79.4 15618 22 200 3295
;
PROC GLM;
   MODEL Y=X1-X4;
run;
/*------------------------------------------------------------------*
 | IML program to carry out regression by sweeping the X variables, |
 | extracting partial and sequential SS from the result.            |
 *------------------------------------------------------------------*/
  Proc IML;
     Reset FW=9;
*-----READ AND PREPARE THE DATA-----;
     USE _LAST_;
     READ ALL INTO  X[ colname=NAME ];
     N = nrow(X);
     K = ncol(X);
     K1 = K + 1;
     X = J( N , 1 , 1) || X;
     NAME1 = { 'INTCEPT'};
     NAME = NAME1 || NAME;
 
*-----TAKE CROSSPRODUCTS------------;
     MEANS = X[ : ,];
     XPX = X` * X;
     print "Raw Cross Product Matrix";
     print , XPX  [ colname = NAME rowname = NAME ];
     print , MEANS[ colname = NAME ];
     SS = XPX[ K1 , K1];
     XNAME = NAME;
     SWEPT = {'SWEPT'};
 
Start SWEEPEM;
     *-----SWEEP THE CROSSPRODUCT MATRIX-;
     print "Sweeping the X variables";
     DO I = 1 TO K;
        XPX = SWEEP( XPX , I);
        I1 = I + 1;
        XNAME [ , I ] = SWEPT;
        print , XPX [ rowname = XNAME colname = XNAME ];
        SS0 = XPX[ K1 , K1 ];
        SEQSS = SEQSS // ( SS - SS0 );
        SS = SS0;
        END;
 
     *-----PREPARE AND PRESENT THE RESULTS--;
     SSE = XPX[ K1 , K1 ];
     MSE = SSE / ( N - K );
     BETA = XPX[ 1:K , K1 ];
     DO I = 1 TO K;
        PARTSS = PARTSS // ( BETA[I,] # BETA[I,] / XPX[I, I] );
        END;
     STDBETA = MSE # VECDIAG( XPX) ;
     STDBETA = SQRT( STDBETA[1:K, ] );
     T = BETA / STDBETA;
     PRT = ( 1. - PROBT( ABS(T) , N - K) ) # 2;
     A = BETA || STDBETA || T || PRT || SEQSS || PARTSS;
     COL = { 'Beta' 'StdDev' 'T Ratio' 'Prob>T' 'Seq SS' 'Part SS' };
     print "Parameter Estimates";
     print A [ colname = COL rowname = NAME ];
 
     print "Correlation Matrix of the Estimates";
     S = 1 / ( SQRT( DIAG( XPX)) );
     CORR = S * XPX * S;
     print CORR [ rowname = NAME colname = NAME FORMAT = 9.3 ];
Finish;
    ;
     Run SWEEPEM;
quit;

