title "Women's labour-force participation, Canada 1977";
/*
Source: Social Change in Canada Project, York Institute for
Social Research.
*/
filename wlfpart "&psy6140\examples\logistic\wlfpart.dat";
proc format;
   value labour    /* labour-force participation */
      1 ='working full-time'
      2 ='working part-time'
      3 ='not working';
   value kids     /* presence of children in the household */
      0 ='Children absent'
      1 ='Children present';
   value region   /* region of Canada */
      1 ='Atlantic Canada'
      2 ='Quebec'
      3 ='Ontario'
      4 ='Prairie provinces'
      5 ='British Columbia';
data wlfpart;
   infile wlfpart;
   input case labour husinc children region;
   working = labour < 3;
   if working then
      fulltime = (labour = 1);
   /* dummy variables for region */
   r1 = (region=1);
   r2 = (region=2);
   r3 = (region=3);
   r4 = (region=4);
proc print data=wlfpart(obs=50);
run;
 
/*NB: Proc Logistic considers the lowest value of the response
      to be the 'event' (usually a 0) whose probability is to be
      modelled.  For the binary responses here, we want 1 to be
      the event, so we sort the data and use order=data.
*/
proc sort;
   by labour;
proc logistic data=wlfpart nosimple order=data;
   model working = husinc children r1-r4;
   title2 'All-main-effects model for Working (Full or Part)';
run;
proc logistic data=wlfpart nosimple;
   model labour  = husinc children ;
   title2 'Proportional Odds Model for Fulltime/Parttime/NotWorking';
run;
 
proc logistic data=wlfpart nosimple order=data;
   model working = husinc children ;
   output out=resultw p=predict;
   title2 'Nested Dichotomies';
proc plot;
   plot predict * husinc = children;
 
proc logistic data=wlfpart nosimple order=data;
   model fulltime = husinc children ;
   output out=resultf p=predict;
proc plot;
   plot predict * husinc = children;
run;
