options linesize=95 ;
title 'Influential Observations in Multiple Regression';
data class;
   input name $ sex $ age height weight;
cards;
Alfred    M 14 69.0 112.5
Alice     F 13 56.5  84.0
Barbara   F 13 65.3  98.0
Carol     F 14 62.8 102.5
Henry     M 14 63.5 102.5
James     M 12 57.3  83.0
Jane      F 12 59.8  84.5
Janet     F 15 62.5 112.5
Jeffrey   M 13 62.5  84.0
John      M 12 59.0  99.5
Joyce     F 11 51.3  50.5
Judy      F 14 64.3  90.0
Louise    F 12 56.3  77.0
Mary      F 15 66.5 112.0
Philip    M 16 72.0 150.0
Robert    M 12 64.8 128.0
Ronald    M 15 67.0 133.0
Thomas    M 11 57.5  85.0
William   M 15 66.5 112.0
;
proc reg data=class;
   id name;
   both:  model weight = height age / p influence;
   output out=results
     r = resid             /* residual, (y - yhat)  */
     p = yhat              /* predicted             */
     h = h                 /* H leverage - how unusual Xs are */
     rstudent = rstudent ; /* studentized resid     */
 
proc plot data=results hpercent=50 vpercent=50;
   plot weight * height = name;
   plot weight * age    = name;
   plot age    * height = name;
   plot rstudent * h    = name;
run;
 
title2 'Wild observation: Small h, large residual';
data wild;
   set class;
   if name='Henry' then do;
      weight = weight + 40;
      name='HENRY';
      end;
proc reg data=wild;
   id name;
   both:  model weight = height age / p influence partial;
   output out=results
     r = resid  p = yhat  h = h  student = rstudent ;
 
proc plot data=results hpercent=50 vpercent=33;
   plot weight * height = name;
   plot weight * age    = name;
   plot age    * height = name;
   plot rstudent * h    = name;
   plot resid  * yhat   = name;
   plot resid  * height = name;
run;
title2 'Wild observation: Large h, large residual';
data wild;
   set class;
   if name='Robert' then do;
      weight = weight + 40;
      name='ROBERT';
      end;
 
proc reg data=wild;
   id name;
   both:  model weight = height age / p influence partial;
   output out=results
     r = resid  p = yhat  h = h  student = rstudent ;
