title 'Stepwise regression simulation example - NO real predictors';
 
/*
  Generate two sets of data:
       100 random predictors (x1-x100), 200 observations
       all statistically independent of the random response (y)
 
  Forward selection finds the predictors which happen to be
  related by chance.  At alpha=.05, expect about 5 'significant'
  variables to be entered in the model.
*/
 
data sim;
   array x{100} x1-x100;
   drop n i;
   do testset= 1 to 2;
      do n=1 to 200;
         *-- generated the predictors;
         do i=1 to 100;
            x(i) = normal(7654321);
            end;
         *-- generate the criterion;
         y = normal(7654321);
         output;
       end;
   end;
 
proc reg data=sim;
   by testset;
   model y = x1-x100 / selection=forward slentry=.05;
   run;
 
/* Now see how well each prediction equation does on the other
   set of data.
   - Each model should do well on the data for which it was
   selected, but poorly on the other set of data.
*/
title2 'Testing cross-validation';
proc reg data=sim;
   by testset;
   M1:  model y = x51 x14 x71 x83 x29 x88 x30 x49 x70 x36 x33;
   M2:  model y = x96 x41 x26 x64 x7  x79 x59;
